bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 2. Aventiure
___________________________________________________
| ### Do wohs in Niderlanden. eins vil edelen kvneges kint ### des vater der hiez Sigemvnt. sin mvoter Sigelint ### in einer rîchen bverge wîten wol bechant ### nidene bi dem Rine div was ze Santen genant ### Sivrit was geheizen <der> snelle degen gvot ### er versvochte vil der riche dvrch ellenthaften mvot ### dvrh sines libes sterche er reit in menegiv lant ### hey waz er sneller degene sit cen Bvrgonden vant
###### 20 | ### In sinen besten ziten bi sinen ivngen tagen ### man mohte michel wnder von Siveride sagen ### waz eren an im wechse vn– wi scoene was sin lip ### sit heten in ce minne div vil wætlichen wip
###### 21 | ### Man zoch in mit dem vlize als im daz wol gezam ### von sin selbes mvote waz tvgende er an sich nam ### des wrden sit gezieret sines vater lant ### daz man in ze allen <dingn> so rehte herlichen vant
###### 22 | ### Er was nv so gewachsen daz er ze hove reit ### di livte in sahen gerne manech frovwe vn– manech [292a] meit ### im wnschten daz sin wille in immer trvege dar ### holt wrden im genvoge des wart der herre wol gewar
###### 23 | ### Vil selten ane hvote man riten lie daz kint ### in hiez mit chleidern ziern Sigmvnt vn– Siglint ### sin phlagen ovch di wisen den êre was bechant ### des moht er wol gewinnen beide livte vnde lant
###### 24 | ### Nv was er in der sterche daz er wol wafen trvoch ### swes er dar zvo bedorfte des lag an im genvoch ### er begvnde mit sinnen werben scoeniv wip ### di trvten wol mit eren des chvenen Sivrides lip
| ### <Do> hiez sin vater Sigmvnt chvnden sinen man ### er wolde hohgecite mit liebn vriwenden han ### div mære man do fvorte in ander chvnege lant ### den vremden vn– den chvnden gab er ross vn– gvot <gwant>
###### 26 | ### Swa man vant deheinen der riter solte sin ### von art der sinen mage div edeln kindelin ### div ladet man zvo dem lande dvrh di hohgecit ### mit dem ivngen kvnege swert genamen si sit
| ### <Von> der hohgecite man mohte wnder sagn ### Sigmvnt <vnde> Siglint di mohten wol beiagn ### mit gvote michel ere des teilte vil ir hant ### des sach man vil der werden nv zin riten in daz lant
###### 28 | ### Vier hvndert swertdegene di solden tragn chleit ### mit samt Sivride vil manech scoeniv meit ### von werche was vnmvezech wan si im waren holt ### vil der edelen steine die frovwen leiten in daz golt
###### 29 | ### die si mit porten wolten wrchen vof ir wat ### den ivngen stolzen rechen des newas niht rat ### der wirt der hiez do sideln vil manegn chvenen man ### ce einen <Svnewenden> da sin svn Sivrid wol riters namn gewan
| ### Do gie ce einem mvenster vil manech richer chneht ### vn– manech edel riter di wisen hetn reht ### daz si den tvmben dienten als in was ê getan ### si heten chvrzewile vnd ovch vil maneger vrevden wan
###### 31 | ### Got man do cen ern eine messe sanch ### do hvop sih von den livten vil michel der gedranch ### da si ce riter wrden nah riterlicher ê ### mit also grozen ern daz wætlich immer mer ergê
###### 32 | ### Si liefen da si fvnden gesatelt manech march ### in hove Sigmvndes der bvhvrt wart so starch ### daz man erdiezen horte Palas vn– Sal ### di hohgemvoten degene di heten grozlichen schal
###### 33 | ### Von wisen vn– von tvmben man horte manegen stoz ### daz der scefte brechen gein <den> lveften doz ### trvonzvne sach man vliegen [292b] fver den palas dan ### von maneges rechen <hende> daz wart mit vlize getan
| ### Der wirt der bat ez lazen do zoch man div march ### man sach ovch da cebrochen vil manege bvkel starch ### vil der edelen steine gevellet v^f daz gras ### ab liehten schildes spangen von hverten daz gescehen was
###### 35 | ### Do giengens wirtes geste da man in sizzen riet ### vil der edelen spise si von ir mvede sciet ### vnt win der aller beste des man in vil getrvoch ### den vremden vn– den chvnden bot man ern genvoch
| ### <Swi> vil si chvrzwile pflagn al den tach ### vil der varender diete rwoe sich bewach ### si dienten nach der gabe di man da riche vant ### des wart mit lobe gezieret allez Sigmvnds lant
###### 37 | ### Der herre der hiez lihen Sivrit den ivngen man ### lant vn– bvrge als er het ê getan ### sinen swertgenozen den gap do vil sin hant ### do liebt in div reise daz si chomn in daz lant
###### 38 | ### Div hohgecit div werte vnz an den sibenden tach ### Siglint div riche nach alten siten pflach ### dvrh ir svns liebe teilen rotez golt ### si chvndez wol gedienen daz im di livte waren holt
###### 39 | ### Vil lvcel man der varnder armen da vant ### ross vnd chleider daz stovb in von der hant ### sam si celebne heten niht mer deheinen tach ### ich wæn ie ingesinde so grozer milte gepflach
| ### <Mit> loblichen eren sciet sich div hohgecit ### von den richen herrn horte man wol sit ### daz si den ivngen wolden ce eime herren han ### des engerte niht her Sivrit der vil wætliche man
###### 41 | ### Sit daz noch beide lebten Sigmvnt vn– Siglint ### niht wolde tragen chrone ir beider liebez chint ### doch wolder wesen herre fver allen den gewalt ### des in den landen vorhte der degen chven vnd balt

<<< Übersicht <<< vorige Seite nächste Seite >>>